@@ -17,6 +17,10 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>
 """
 
+from sympy import *
 from applpy import *
+init_session()
+import sys
+sys.display_hook=pprint
 
 
