@@ -39,6 +39,22 @@ Continuous Distributions
 
 """
 
+class ArcSinRV(RV):
+    def __init__(self):
+        X_dummy=RV(1/(pi*sqrt(x*(1-x))),[0,1])
+        self.func=X_dummy.func
+        self.support=X_dummy.support
+        self.ftype=X_dummy.ftype
+
+class ArcTanRV(RV):
+    def __init__(self,alpha=Symbol('alpha',positive=True),
+                 phi=Symbol('phi')):
+        X_dummy=RV(alpha/(atan(alpha*phi)+pi/2)*(1+alpha**2*(x-phi)**2),
+                   [0,oo])
+        self.func=X_dummy.func
+        self.support=X_dummy.support
+        self.ftype=X_dummy.ftype
+
 class BetaRV(RV):
     def __init__(self,alpha=Symbol('alpha',positive=True),
                  beta=Symbol('beta'),positive=True):
@@ -100,6 +116,25 @@ class ErlangRV(RV):
         self.support=X_dummy.support
         self.ftype=X_dummy.ftype
 
+class ErrorRV(RV):
+    def __init__(self,mu=Symbol('mu',positive=True),
+                 alpha=Symbol('alpha'),d=Symbol('d')):
+        X_dummy=RV(mu*exp(-abs(mu*(x-d1))**alpha)/
+                   (2*gamma(1+1/alpha)),[-oo,oo])
+        self.func=X_dummy.func
+        self.support=X_dummy.support
+        self.ftype=X_dummy.ftype
+
+class ErrorIIRV(RV):
+    def __init__(self,a=Symbol('a'),b=Symbol('b'),
+                 c=Symbol('c')):
+        X_dummy=RV(exp(-((abs(x-a))**(2/c)/(2*b))/
+                       ((b**(c/2))*2**(c/2+1)*gamma(c/2+1))),
+                   [-oo,oo])
+        self.func=X_dummy.func
+        self.support=X_dummy.support
+        self.ftype=X_dummy.ftype
+
 class ExponentialRV(RV):
     def __init__(self,theta=Symbol('theta',positive=True)):
         X_dummy=RV([theta*exp(-theta*x)],[0,oo])
@@ -179,6 +214,16 @@ class ExtremeValueRV(RV):
             varlist.append(var)
         return varlist
 
+class FRV(RV):
+    def __init__(self,n1=Symbol('n1',positive=True),
+                 n2=Symbol('n2',positive=True)):
+        X_dummy=RV(gamma((n1+n2)/2)*(n1/n2)**(n/2)*x**(n/2-1)/
+                   gamma(n1/2)*gamma(n2/2)*((n1/n2)*x+1)**((n1+n2)/2),
+                   [0,oo])
+        self.func=X_dummy.func
+        self.support=X_dummy.support
+        self.ftype=X_dummy.ftype
+
 class GammaRV(RV):
     def __init__(self,theta=Symbol('theta'),kappa=Symbol('kappa')):
         X_dummy=RV((theta*(theta*x)**(kappa-1)*exp(-theta*x))/(gamma(kappa)),
@@ -188,6 +233,15 @@ class GammaRV(RV):
         self.ftype=X_dummy.ftype
         self.parameter=[theta,kappa]
 
+class GeneralizedParetoRV(RV):
+    def __init__(self,theta=Symbol('theta',positive=True),
+                 delta=Symbol('delta'),kappa=Symbol('kappa')):
+        X_dummy=RV((theta+kappa/(x+delta))*(1+x/delta)**(-kappa)*
+                   exp(-theta*x),[0,oo])
+        self.func=X_dummy.func
+        self.support=X_dummy.support
+        self.ftype=X_dummy.ftype
+
 class GompertzRV(RV):
     def __init__(self,theta=Symbol('theta',positive=True),
                  kappa=Symbol('kappa')):
@@ -215,6 +269,15 @@ class GompertzRV(RV):
             varlist.append(var)
         return varlist
 
+class IDBRV(RV):
+    def __init__(self,theta=Symbol('theta'),delta=Symbol('delta'),
+                 kappa=Symbol('kappa')):
+        X_dummy=RV(1-(1+kappa*x)**(-theta/kappa)*
+                   exp(-delta*x**2/2),[0,oo])
+        self.func=X_dummy.func
+        self.support=X_dummy.support
+        self.ftype=X_dummy.ftype
+
 class InverseGaussianRV(RV):
     def __init__(self,theta=Symbol('theta',positive=True),
                  mu=Symbol('mu',positive=True)):
@@ -236,6 +299,164 @@ class InverseGammaRV(RV):
         self.support=X_dummy.support
         self.ftype=X_dummy.ftype
 
+class KSRV(RV):
+    def __init__(self,n=Symbol('n',positive=True)):
+        #Phase 1
+        N=n
+        m=floor(3*N/2)+(N%2)-1
+        vv=range(m+1)
+        vval=[]
+        for i in range(len(vv)):
+            vval.append(None)
+        vv=dict(zip(vv,vval))
+        vv[0]=0
+        g=1/(2*N)
+        mm=0
+        for i in range(1,N):
+            mm+=1
+            vv[mm]=i*g
+        for j in range(2*floor(N/2)+1,2*N,2):
+            mm+=1
+            vv[mm]=j*g
+        #Phase 2
+        # Generate the c array
+        cidx=[];cval=[]
+        for k in range(1,m+1):
+            cidx.append(k)
+            cval.append((vv[k-1]+vv[k])/2)
+        c=dict(zip(cidx,cval))
+        # Generate the x array
+        xidx=[];xval=[]
+        for k in range(1,N+1):
+            xidx.append(k)
+            xval.append((2*k-1)*g)
+        x=dict(zip(xidx,xval))
+        # Generate an NxN A array
+        aidx=range(1,N+1);aval=[]
+        for i in aidx:
+            aval.append(None)
+        arow=dict(zip(aidx,aval));A=dict(zip(aidx,aval))
+        for i in aidx:
+            A[i]=arow
+        # Insert values into the A array
+        for i in range(2,N+1):
+            for j in range(1,i):
+                A[i][j]=0
+        for k in range(1,m+1):
+            for i in range(1,N+1):
+                for j in range(i,N+1):
+                    A[i][j]=0
+            z=max(floor(N*c[k]-1/2),0)
+            l=min(floor(2*N*c[k])+1,N)
+            for i in range(1,N+1):
+                for j in range(max(i,z+1),min(N,i+l-1)+1):
+                    A[i][j]=1
+        # Create a 1xm P array
+        Pidx=[];Pval=[]
+        for i in range(1,m+1):
+            Pidx.append(i)
+            Pval.append(None)
+        P=dict(zip(Pidx,Pval))
+        # Create an NxN F array
+        fidx=range(1,N+1);fval=[]
+        for i in fidx:
+            fval.append(None)
+        frow=dict(zip(fidx,fval));F=dict(zip(fidx,fval))
+        for i in fidx:
+            F[i]=frow
+        # Create an NxN V array
+        vidx=range(1,N+1);vval=[]
+        for i in vidx:
+            vval.append(None)
+        vrow=dict(zip(vidx,vval));V=dict(zip(vidx,vval))
+        for i in vidx:
+            V[i]=vrow
+        # Create a list of indexed u variables
+        varstring='u:'+str(N+1)
+        u=symbols(varstring)
+        for k in range(2,m+1):
+            z=int(max(floor(N*c[k]-1/2),0))
+            l=int(min(floor(2*N*c[k])+1,N))
+            F[N][N]=integrate(1,(u[N],x[N]-v,1))
+            V[N][N]=integrate(1,(u[N],u[N-1],1))
+            for i in reversed(range(2,N,-1)):
+                if i+l>N:
+                    S=0
+                else:
+                    S=F[i+1][i+l]
+                if i+l>N+1:
+                    F[i][N]=integrate(V[i+1][N],
+                                      (u[i],x[N]-v,floor(x[i]+c[k])))
+                    V[i][N]=integrate(V[i+1][N],
+                                      (u[i],u[i-1],floor(x[i]+c[k])))
+                if i+l==N+1:
+                    F[i][N]=integrate(V[i+1][N],
+                                      (u[i],x[N]-v,x[i]+v))
+                if i+l<N+1:
+                    F[i][i+l-1]=integrate(V[i+1][i+l-1]+S,
+                                          (u[i],x[N]-v,x[i]+v))
+                S+=F[i+1][min(i+l-1,N)]
+                for j in reversed(range(max(i+1,z+2),min(N-1,i+l-2)+1,-1)):
+                    F[i][j]=integrate(V[i+1][j]+S,
+                                      (u[i],x[j]-v,x[j+1]-v))
+                    V[i][j]=integrate(V[i+1][j]+S,
+                                      (u[i],u[i-1],x[j+1]-v))
+                    S+=F[i+1][j]
+                if z+1<=i:
+                    V[i][i]=integrate(S,(u[i],u[i-1],x[i+1]-v))
+                if z+1>i:
+                    V[i][z+1]=integrate(V[i+1][z+1]+S,
+                                        (u[i],u[i-1],x[z+2]-v))
+                if z+1<i:
+                    F[i][i]=integrate(S,(u[i],x[i]-v,x[i+1]-v))
+            if l==N:
+                S=0
+            else:
+                S=F[2][l+1]
+            if l<N:
+                F[1][l]=integrate(V[2][l]+S,(u[1],x[l]-v,x[1]+v))
+            S+=F[2][j]
+            for j in reversed(range(max(2,z+1),min(N-1,l-1)+1,-1)):
+                F[1][j]=integrate(V[2][j]+S,
+                                  (u[1],(x[j]-v)*(floor(x[j]-c[k])+1),
+                               x[j+1]-v))
+                S+=F[2][j]
+            if z==0:
+                F[1][1]=integrate(S,(u[1],0,x[2]-v))
+            P[k]=0
+            for j in range(z+1,l+1):
+                P[k]+=F[1][j]
+            P[k]=factorial(N)*P[k]
+        # Create the support and function list for the KSRV
+        KSspt=[];KSCDF=[]
+        x=Symbol('x')
+        for i in range(0,m+1):
+            KSspt.append(vv[i]+1/(2*N))
+        for i in range(1,m+1):
+            func=(x-1)/(2*N)
+            KSCDF.append(simplify(func.subs(v,P[i])))
+        # Remove redundant elements from the list
+        KSCDF2=[];KSspt2=[]
+        KSspt2.append(KSspt[0])
+        KSCDF2.append(KSCDF[0])
+        for i in range(1,len(KSCDF)):
+            if KSCDF[i]!=KSCDF[i-1]:
+                KSCDF2.append(KSCDF[i])
+                KSspt2.append(KSspt[i])
+        KSspt2.append(KSspt[-1])
+        X_dummy=RV(KSCDF2,KSspt2,['continuous','cdf'])
+        self.func=X_dummy.func
+        self.support=X_dummy.support
+        self.ftype=X_dummy.ftype
+
+class LaPlaceRV(RV):
+    def __init__(self,omega=Symbol('omega',positive=True),
+                 theta=Symbol('theta')):
+        X_dummy=RV(exp(-abs(x-theta)/omega)/(2*omega),[-oo,oo])
+        self.func=X_dummy.func
+        self.support=X_dummy.support
+        self.ftype=X_dummy.ftype
+        
 class LogGammaRV(RV):
     def __init__(self,alpha=Symbol('alpha',positive=True),
                  beta=Symbol('beta',positive=True)):
@@ -300,7 +521,7 @@ class LogLogisticRV(RV):
 class LogNormalRV(RV):
     def __init__(self,mu=Symbol('mu'),
                  sigma=Symbol('sigma',positive=True)):
-        X_dummy=([(1/2)*(sqrt(2)*exp((-1/2)*((ln(x)-mu)**2)/(sigma**2)))/
+        X_dummy=RV([(1/2)*(sqrt(2)*exp((-1/2)*((ln(x)-mu)**2)/(sigma**2)))/
                   (sqrt(pi)*x*sigma)],[0,oo])
         self.func=X_dummy.func
         self.support=X_dummy.support
@@ -309,7 +530,7 @@ class LogNormalRV(RV):
 class LomaxRV(RV):
     def __init__(self,kappa=Symbol('kappa',positive=True),
                  theta=Symbol('theta',positive=True)):
-        X_dummy=([theta*kappa*(1+theta*x)**(-kappa-1)],[0,oo])
+        X_dummy=RV([theta*kappa*(1+theta*x)**(-kappa-1)],[0,oo])
         self.func=X_dummy.func
         self.support=X_dummy.support
         self.ftype=X_dummy.ftype
@@ -330,6 +551,16 @@ class LomaxRV(RV):
             varlist.append(var)
         return varlist
 
+class MakehamRV(RV):
+    def __init__(self,theta=Symbol('theta',positive=True),
+                 delta=Symbol('delta',positive=True),
+                 kappa=Symbol('kappa')):
+        X_dummy=RV((theta+delta*kappa**x)*
+                   exp(-theta*x-delta*(kappa**x-1)/log(kappa)),[0,oo])
+        self.func=X_dummy.func
+        self.support=X_dummy.support
+        self.ftype=X_dummy.ftype
+
 class MuthRV(RV):
     def __init__(self,kappa=Symbol('kappa',positive=True)):
         X_dummy=RV([(exp(kappa*x)-kappa)*exp((-exp(kappa*x)/kappa)+
@@ -383,13 +614,13 @@ class TRV(RV):
 
 class UniformRV(RV):
     def __init__(self,a=Symbol('a'),b=Symbol('b')):
-        X_dummy=RV((b-a)**(-1),[a,b])
+        X_dummy=RV(simplify((b-a)**(-1)),[a,b])
         self.func=X_dummy.func
         self.support=X_dummy.support
         self.ftype=X_dummy.ftype
         self.parameter=[a,b]
 
-    def variate(self,n=1,sim='sim'):
+    def variate(self,n=1,s='sim'):
         # If no parameter is specified, return an error
         if param_check(self.parameter)==False:
             raise RVError('Not all parameters specified')
